# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'ui/dock_portfolio.ui'
#
# Created by: PyQt5 UI code generator 5.15.0
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_DockPortfolio(object):
    def setupUi(self, DockPortfolio):
        DockPortfolio.setObjectName("DockPortfolio")
        DockPortfolio.resize(405, 325)
        DockPortfolio.setAutoFillBackground(False)
        DockPortfolio.setLocale(QtCore.QLocale(QtCore.QLocale.English, QtCore.QLocale.UnitedStates))
        DockPortfolio.setFeatures(QtWidgets.QDockWidget.AllDockWidgetFeatures)
        DockPortfolio.setAllowedAreas(QtCore.Qt.BottomDockWidgetArea|QtCore.Qt.TopDockWidgetArea)
        self.dockWidgetContents = QtWidgets.QWidget()
        self.dockWidgetContents.setObjectName("dockWidgetContents")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.dockWidgetContents)
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.tabla = QtWidgets.QTableView(self.dockWidgetContents)
        self.tabla.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
        self.tabla.setEditTriggers(QtWidgets.QAbstractItemView.NoEditTriggers)
        self.tabla.setAlternatingRowColors(True)
        self.tabla.setSelectionMode(QtWidgets.QAbstractItemView.SingleSelection)
        self.tabla.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.tabla.setGridStyle(QtCore.Qt.SolidLine)
        self.tabla.setObjectName("tabla")
        self.tabla.verticalHeader().setVisible(False)
        self.horizontalLayout.addWidget(self.tabla)
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setSizeConstraint(QtWidgets.QLayout.SetMinimumSize)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.combo_trades = QtWidgets.QComboBox(self.dockWidgetContents)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.combo_trades.sizePolicy().hasHeightForWidth())
        self.combo_trades.setSizePolicy(sizePolicy)
        self.combo_trades.setMaximumSize(QtCore.QSize(200, 16777215))
        self.combo_trades.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.combo_trades.setInsertPolicy(QtWidgets.QComboBox.InsertAtTop)
        self.combo_trades.setObjectName("combo_trades")
        self.combo_trades.addItem("")
        self.combo_trades.addItem("")
        self.verticalLayout_2.addWidget(self.combo_trades)
        self.formLayout = QtWidgets.QFormLayout()
        self.formLayout.setSizeConstraint(QtWidgets.QLayout.SetMinimumSize)
        self.formLayout.setObjectName("formLayout")
        self.label = QtWidgets.QLabel(self.dockWidgetContents)
        self.label.setObjectName("label")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label)
        self.ed_profit100_total = QtWidgets.QLineEdit(self.dockWidgetContents)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.ed_profit100_total.sizePolicy().hasHeightForWidth())
        self.ed_profit100_total.setSizePolicy(sizePolicy)
        self.ed_profit100_total.setMaximumSize(QtCore.QSize(100, 16777215))
        self.ed_profit100_total.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.ed_profit100_total.setReadOnly(True)
        self.ed_profit100_total.setCursorMoveStyle(QtCore.Qt.LogicalMoveStyle)
        self.ed_profit100_total.setObjectName("ed_profit100_total")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.ed_profit100_total)
        self.verticalLayout_2.addLayout(self.formLayout)
        self.horizontalLayout.addLayout(self.verticalLayout_2)
        self.verticalLayout.addLayout(self.horizontalLayout)
        DockPortfolio.setWidget(self.dockWidgetContents)

        self.retranslateUi(DockPortfolio)
        QtCore.QMetaObject.connectSlotsByName(DockPortfolio)

    def retranslateUi(self, DockPortfolio):
        _translate = QtCore.QCoreApplication.translate
        DockPortfolio.setWindowTitle(_translate("DockPortfolio", "Po&rtfolio"))
        self.combo_trades.setItemText(0, _translate("DockPortfolio", "Open"))
        self.combo_trades.setItemText(1, _translate("DockPortfolio", "Closed"))
        self.label.setText(_translate("DockPortfolio", "Profit total:"))
import iconos_rc
