# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '/home/q/dev/qtradingview/qtradingview/ui/dock_alarms.ui'
#
# Created by: PyQt5 UI code generator 5.15.1
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_DockAlarms(object):
    def setupUi(self, DockAlarms):
        DockAlarms.setObjectName("DockAlarms")
        DockAlarms.resize(611, 412)
        DockAlarms.setToolTip("")
        DockAlarms.setLocale(QtCore.QLocale(QtCore.QLocale.English, QtCore.QLocale.UnitedStates))
        DockAlarms.setFeatures(QtWidgets.QDockWidget.AllDockWidgetFeatures)
        DockAlarms.setAllowedAreas(QtCore.Qt.AllDockWidgetAreas)
        self.dockWidgetContents = QtWidgets.QWidget()
        self.dockWidgetContents.setObjectName("dockWidgetContents")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.dockWidgetContents)
        self.verticalLayout.setObjectName("verticalLayout")
        self.tb_alarms = QtWidgets.QTableView(self.dockWidgetContents)
        self.tb_alarms.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
        self.tb_alarms.setAlternatingRowColors(True)
        self.tb_alarms.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.tb_alarms.setObjectName("tb_alarms")
        self.tb_alarms.verticalHeader().setVisible(False)
        self.verticalLayout.addWidget(self.tb_alarms)
        self.btn_clear = QtWidgets.QPushButton(self.dockWidgetContents)
        self.btn_clear.setObjectName("btn_clear")
        self.verticalLayout.addWidget(self.btn_clear)
        DockAlarms.setWidget(self.dockWidgetContents)

        self.retranslateUi(DockAlarms)
        QtCore.QMetaObject.connectSlotsByName(DockAlarms)

    def retranslateUi(self, DockAlarms):
        _translate = QtCore.QCoreApplication.translate
        self.btn_clear.setText(_translate("DockAlarms", "Clear"))
