# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '/home/q/dev/qtradingview/qtradingview/ui/dialog_alarm.ui'
#
# Created by: PyQt5 UI code generator 5.15.1
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_dialogAlarm(object):
    def setupUi(self, dialogAlarm):
        dialogAlarm.setObjectName("dialogAlarm")
        dialogAlarm.setWindowModality(QtCore.Qt.NonModal)
        dialogAlarm.resize(242, 440)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(dialogAlarm.sizePolicy().hasHeightForWidth())
        dialogAlarm.setSizePolicy(sizePolicy)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/actions/actions/alarms.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        dialogAlarm.setWindowIcon(icon)
        dialogAlarm.setLocale(QtCore.QLocale(QtCore.QLocale.English, QtCore.QLocale.UnitedStates))
        self.verticalLayout = QtWidgets.QVBoxLayout(dialogAlarm)
        self.verticalLayout.setObjectName("verticalLayout")
        self.group_info = QtWidgets.QGroupBox(dialogAlarm)
        self.group_info.setFlat(True)
        self.group_info.setObjectName("group_info")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.group_info)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.ed_exchange = QtWidgets.QLineEdit(self.group_info)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.ed_exchange.sizePolicy().hasHeightForWidth())
        self.ed_exchange.setSizePolicy(sizePolicy)
        self.ed_exchange.setLocale(QtCore.QLocale(QtCore.QLocale.English, QtCore.QLocale.UnitedStates))
        self.ed_exchange.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.ed_exchange.setReadOnly(True)
        self.ed_exchange.setObjectName("ed_exchange")
        self.verticalLayout_3.addWidget(self.ed_exchange)
        self.ed_market = QtWidgets.QLineEdit(self.group_info)
        self.ed_market.setLocale(QtCore.QLocale(QtCore.QLocale.English, QtCore.QLocale.UnitedStates))
        self.ed_market.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.ed_market.setReadOnly(True)
        self.ed_market.setObjectName("ed_market")
        self.verticalLayout_3.addWidget(self.ed_market)
        self.line_2 = QtWidgets.QFrame(self.group_info)
        self.line_2.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_2.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_2.setObjectName("line_2")
        self.verticalLayout_3.addWidget(self.line_2)
        self.ed_lastPrice = QtWidgets.QLineEdit(self.group_info)
        self.ed_lastPrice.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.ed_lastPrice.setReadOnly(True)
        self.ed_lastPrice.setObjectName("ed_lastPrice")
        self.verticalLayout_3.addWidget(self.ed_lastPrice)
        self.verticalLayout.addWidget(self.group_info)
        self.group_condition = QtWidgets.QGroupBox(dialogAlarm)
        self.group_condition.setFlat(False)
        self.group_condition.setObjectName("group_condition")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.group_condition)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.cb_condition = QtWidgets.QComboBox(self.group_condition)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.cb_condition.sizePolicy().hasHeightForWidth())
        self.cb_condition.setSizePolicy(sizePolicy)
        self.cb_condition.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.cb_condition.setLocale(QtCore.QLocale(QtCore.QLocale.English, QtCore.QLocale.UnitedStates))
        self.cb_condition.setObjectName("cb_condition")
        self.verticalLayout_2.addWidget(self.cb_condition)
        self.spin_price = QtWidgets.QDoubleSpinBox(self.group_condition)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.spin_price.sizePolicy().hasHeightForWidth())
        self.spin_price.setSizePolicy(sizePolicy)
        self.spin_price.setLocale(QtCore.QLocale(QtCore.QLocale.English, QtCore.QLocale.UnitedStates))
        self.spin_price.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.spin_price.setButtonSymbols(QtWidgets.QAbstractSpinBox.UpDownArrows)
        self.spin_price.setDecimals(8)
        self.spin_price.setObjectName("spin_price")
        self.verticalLayout_2.addWidget(self.spin_price)
        self.ck_autodelete = QtWidgets.QCheckBox(self.group_condition)
        self.ck_autodelete.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.ck_autodelete.setLocale(QtCore.QLocale(QtCore.QLocale.English, QtCore.QLocale.UnitedStates))
        self.ck_autodelete.setChecked(True)
        self.ck_autodelete.setObjectName("ck_autodelete")
        self.verticalLayout_2.addWidget(self.ck_autodelete)
        self.verticalLayout.addWidget(self.group_condition)
        self.buttonBox = QtWidgets.QDialogButtonBox(dialogAlarm)
        self.buttonBox.setLocale(QtCore.QLocale(QtCore.QLocale.English, QtCore.QLocale.UnitedStates))
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Cancel|QtWidgets.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName("buttonBox")
        self.verticalLayout.addWidget(self.buttonBox)

        self.retranslateUi(dialogAlarm)
        self.buttonBox.accepted.connect(dialogAlarm.accept)
        self.buttonBox.rejected.connect(dialogAlarm.reject)
        QtCore.QMetaObject.connectSlotsByName(dialogAlarm)

    def retranslateUi(self, dialogAlarm):
        _translate = QtCore.QCoreApplication.translate
        dialogAlarm.setWindowTitle(_translate("dialogAlarm", "Alarm"))
        self.group_info.setTitle(_translate("dialogAlarm", "Market"))
        self.ed_lastPrice.setToolTip(_translate("dialogAlarm", "Show last price of this market"))
        self.group_condition.setTitle(_translate("dialogAlarm", "Condition"))
        self.ck_autodelete.setText(_translate("dialogAlarm", "Autodelete when complished"))
import iconos_rc
