# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '/home/q/dev/qtradingview/qtradingview/ui/dialog_trade.ui'
#
# Created by: PyQt5 UI code generator 5.15.1
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_DialogTrade(object):
    def setupUi(self, DialogTrade):
        DialogTrade.setObjectName("DialogTrade")
        DialogTrade.resize(243, 240)
        DialogTrade.setModal(True)
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(DialogTrade)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.formLayout = QtWidgets.QFormLayout()
        self.formLayout.setSizeConstraint(QtWidgets.QLayout.SetMaximumSize)
        self.formLayout.setObjectName("formLayout")
        self.label = QtWidgets.QLabel(DialogTrade)
        self.label.setObjectName("label")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label)
        self.label_2 = QtWidgets.QLabel(DialogTrade)
        self.label_2.setObjectName("label_2")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_2)
        self.label_3 = QtWidgets.QLabel(DialogTrade)
        self.label_3.setObjectName("label_3")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.label_3)
        self.label_4 = QtWidgets.QLabel(DialogTrade)
        self.label_4.setObjectName("label_4")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.label_4)
        self.ed_market = QtWidgets.QLineEdit(DialogTrade)
        self.ed_market.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.ed_market.setReadOnly(True)
        self.ed_market.setObjectName("ed_market")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.ed_market)
        self.combo_type = QtWidgets.QComboBox(DialogTrade)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.combo_type.sizePolicy().hasHeightForWidth())
        self.combo_type.setSizePolicy(sizePolicy)
        self.combo_type.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.combo_type.setObjectName("combo_type")
        self.combo_type.addItem("")
        self.combo_type.addItem("")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.combo_type)
        self.spin_price = QtWidgets.QDoubleSpinBox(DialogTrade)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.spin_price.sizePolicy().hasHeightForWidth())
        self.spin_price.setSizePolicy(sizePolicy)
        self.spin_price.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.spin_price.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.spin_price.setButtonSymbols(QtWidgets.QAbstractSpinBox.UpDownArrows)
        self.spin_price.setDecimals(8)
        self.spin_price.setMaximum(9999999.99)
        self.spin_price.setObjectName("spin_price")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.spin_price)
        self.label_5 = QtWidgets.QLabel(DialogTrade)
        self.label_5.setObjectName("label_5")
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.label_5)
        self.spin_amount = QtWidgets.QDoubleSpinBox(DialogTrade)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.spin_amount.sizePolicy().hasHeightForWidth())
        self.spin_amount.setSizePolicy(sizePolicy)
        self.spin_amount.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.spin_amount.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.spin_amount.setDecimals(8)
        self.spin_amount.setMaximum(9999999.99)
        self.spin_amount.setObjectName("spin_amount")
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.spin_amount)
        self.ed_exchange = QtWidgets.QLineEdit(DialogTrade)
        self.ed_exchange.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.ed_exchange.setReadOnly(True)
        self.ed_exchange.setObjectName("ed_exchange")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.ed_exchange)
        self.verticalLayout.addLayout(self.formLayout)
        self.verticalLayout_2.addLayout(self.verticalLayout)
        self.buttonBox = QtWidgets.QDialogButtonBox(DialogTrade)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Cancel|QtWidgets.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName("buttonBox")
        self.verticalLayout_2.addWidget(self.buttonBox)

        self.retranslateUi(DialogTrade)
        self.buttonBox.accepted.connect(DialogTrade.accept)
        self.buttonBox.rejected.connect(DialogTrade.close)
        QtCore.QMetaObject.connectSlotsByName(DialogTrade)

    def retranslateUi(self, DialogTrade):
        _translate = QtCore.QCoreApplication.translate
        DialogTrade.setWindowTitle(_translate("DialogTrade", "Trade"))
        self.label.setText(_translate("DialogTrade", "Exchange"))
        self.label_2.setText(_translate("DialogTrade", "Market"))
        self.label_3.setText(_translate("DialogTrade", "Type"))
        self.label_4.setText(_translate("DialogTrade", "Price"))
        self.combo_type.setItemText(0, _translate("DialogTrade", "Long"))
        self.combo_type.setItemText(1, _translate("DialogTrade", "Short"))
        self.label_5.setText(_translate("DialogTrade", "Amount"))
